@@ -1062,7 +1062,7 @@ class Builder(Update):
         # imported from calculate_assemble
         chrootPath = self.clVars.Get('cl_builder_path')
         pkgDir = pathJoin(chrootPath,
-                          self.clVars.Get('cl_builder_pkgdir'))
+                          self.clVars.Get('cl_builder_pkgdir_full'))
         dbPkg = pathJoin(chrootPath, 'var/db/pkg')
 
         logfile = self._get_log_file()
@@ -1553,10 +1553,9 @@ class Builder(Update):
         deo = self.get_default_emerge_opts()
         logfile = self._get_log_file()
         # в случае использования base binhost
-        env_update = {}
+        env_update = {'PKGDIR': self.clVars.Get('cl_builder_pkgdir_full')}
         if self.clVars.GetBool('cl_builder_binhost_base_set'):
-            env_update = {"PKGDIR": self.clVars.Get('cl_builder_pkgdir_stable'),
-                          "FEATURES": "-getbinpkg"}
+            env_update["FEATURES"] = "-getbinpkg"
             # удалить Packages файл, для того, чтобы он переформировался при
             # следующем вызове emerge
             index_fn = path.join(env_update['PKGDIR'], "Packages")
